.. _api-target:

Target
======

The Target class represents the target body in a crater simulation. It encapsulates properties of the target, such as its material composition, size, and other physical characteristics.


.. autoclass:: cratermaker.components.target.Target
    :members:
    :inherited-members:
    :no-index:

